@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert to and from Baha'i dates
 
-our $VERSION = '0.2001';
+our $VERSION = '0.2100';
 
 
 use strict;
@@ -254,7 +254,7 @@ sub as_string {
     }
     elsif (!$args{size} && $args{numeric} && !$args{alpha}) {
         # short numeric
-        $date .= sprintf '%s/%s/%s', @$date_hash{qw(month day year)};
+        $date .= sprintf '%s/%s/%s', @$date_hash{qw(year month day)};
     }
     elsif ($args{size} && $args{numeric}) {
         # long numeric
@@ -466,7 +466,7 @@ Date::Baha::i - Convert to and from Baha'i dates
 
 =head1 VERSION
 
-version 0.2001
+version 0.2100
 
 =head1 SYNOPSIS
 
@@ -729,7 +729,7 @@ representations on or off.  The defaults are as follows:
 Here are some handy examples (newlines added for readability):
 
   short numeric:
-  1/1/159
+  159/11/6  # year/month/day
 
   long numeric:
   7th day of the week, 1st day of the 1st month, year 159,
@@ -814,8 +814,6 @@ L<http://calendar.bahaiq.com/>
 
 =head1 TO DO
 
-Re-create the missing 01-as_string.t, 03-misc.t & 04-to_bahai.t tests!
-
 Base the date computation on the time of day (Baha'i day begins at sunset).
 
 Make this a L<DateTime> module.
